@@ -11,10 +11,15 @@ collect_ignore = ["root"]
 
 
 def pytest_configure(config):
-    config.addinivalue_line(
-        "markers",
-        "disable_env: disable setting the READTHEDOCS_PROJECT environment variable.",
-    )
+    markers = [
+        "disable_env: disable setting the READTHEDOCS_PROJECT environment variable."
+        "do_not_patch_connection: do not patch socket.create_connection (it is patched by default in tests to skip internet availability check)."
+    ]
+    for marker in markers:
+        config.addinivalue_line(
+            "markers",
+            marker,
+        )
 
 
 @pytest.fixture(scope="session")
@@ -37,6 +42,13 @@ def non_html_format_builders():
     return ["latex", "text", "man", "texinfo", "texinfo", "xml"]
 
 
+@pytest.fixture(autouse=True)
+def mock_internet_connection(mocker, request):
+    if "do_not_patch_connection" in request.keywords:
+        return
+    mocker.patch("socket.create_connection")
+
+
 @pytest.fixture
 def master_index(mocker):
     master_index = dedent(
